@@ -70,6 +70,8 @@ class SNR(Metric):
         and Signal Processing (ICASSP) 2019.
 
     """
+    is_differentiable = True
+    higher_is_better = True
     sum_snr: Tensor
     total: Tensor
 
@@ -107,7 +109,3 @@ class SNR(Metric):
     def compute(self) -> Tensor:
         """Computes average SNR."""
         return self.sum_snr / self.total
-
-    @property
-    def is_differentiable(self) -> bool:
-        return True
