@@ -21,9 +21,8 @@ from torchmetrics.metric import Metric
 
 
 class ConfusionMatrix(Metric):
-    """
-    Computes the `confusion matrix
-    <https://scikit-learn.org/stable/modules/model_evaluation.html#confusion-matrix>`_.  Works with binary,
+    r"""
+    Computes the `confusion matrix`_.  Works with binary,
     multiclass, and multilabel data.  Accepts probabilities or logits from a model output or integer class
     values in prediction. Works with multi-dimensional preds and target, but it should be noted that
     additional dimensions will be flattened.
@@ -39,8 +38,7 @@ class ConfusionMatrix(Metric):
     If preds has an extra dimension as in the case of multi-class scores we perform an argmax on ``dim=1``.
 
     If working with multilabel data, setting the `is_multilabel` argument to `True` will make sure that a
-    `confusion matrix gets calculated per label
-    <https://scikit-learn.org/stable/modules/generated/sklearn.metrics.multilabel_confusion_matrix.html>`_.
+    `confusion matrix gets calculated per label`_.
 
     Args:
         num_classes: Number of classes in the dataset.
@@ -91,7 +89,9 @@ class ConfusionMatrix(Metric):
         tensor([[[1., 0.], [0., 1.]],
                 [[1., 0.], [1., 0.]],
                 [[0., 1.], [0., 1.]]])
+
     """
+    is_differentiable = False
     confmat: Tensor
 
     def __init__(
@@ -114,7 +114,7 @@ class ConfusionMatrix(Metric):
         self.threshold = threshold
         self.multilabel = multilabel
 
-        allowed_normalize = ('true', 'pred', 'all', 'none', None)
+        allowed_normalize = ("true", "pred", "all", "none", None)
         if self.normalize not in allowed_normalize:
             raise ValueError(f"Argument average needs to one of the following: {allowed_normalize}")
 
@@ -122,8 +122,7 @@ class ConfusionMatrix(Metric):
         self.add_state("confmat", default=default, dist_reduce_fx="sum")
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
-        """
-        Update state with predictions and targets.
+        """Update state with predictions and targets.
 
         Args:
             preds: Predictions from model
@@ -133,15 +132,10 @@ class ConfusionMatrix(Metric):
         self.confmat += confmat
 
     def compute(self) -> Tensor:
-        """
-        Computes confusion matrix.
+        """Computes confusion matrix.
 
         Returns:
             If `multilabel=False` this will be a `[n_classes, n_classes]` tensor and if `multilabel=True`
             this will be a `[n_classes, 2, 2]` tensor
         """
         return _confusion_matrix_compute(self.confmat, self.normalize)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
