@@ -23,7 +23,7 @@ from torchmetrics.utilities.enums import AverageMethod
 
 class FBeta(StatScores):
     r"""
-    Computes `F-score <https://en.wikipedia.org/wiki/F-score>`_, specifically:
+    Computes `F-score`_, specifically:
 
     .. math::
         F_\beta = (1 + \beta^2) * \frac{\text{precision} * \text{recall}}
@@ -169,16 +169,13 @@ class FBeta(StatScores):
         self.average = average
 
     def compute(self) -> Tensor:
-        """
-        Computes fbeta over state.
-        """
+        """Computes fbeta over state."""
         tp, fp, tn, fn = self._get_final_stats()
         return _fbeta_compute(tp, fp, tn, fn, self.beta, self.ignore_index, self.average, self.mdmc_reduce)
 
 
 class F1(FBeta):
-    """
-    Computes F1 metric. F1 metrics correspond to a harmonic mean of the precision and recall scores.
+    """Computes F1 metric. F1 metrics correspond to a harmonic mean of the precision and recall scores.
 
     Works with binary, multiclass, and multilabel data. Accepts logits or probabilities from a model
     output or integer class values in prediction. Works with multi-dimensional preds and target.
@@ -272,6 +269,9 @@ class F1(FBeta):
         tensor(0.3333)
     """
 
+    is_differentiable = False
+    higher_is_better = True
+
     def __init__(
         self,
         num_classes: Optional[int] = None,
@@ -298,9 +298,5 @@ class F1(FBeta):
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
             process_group=process_group,
-            dist_sync_fn=dist_sync_fn
+            dist_sync_fn=dist_sync_fn,
         )
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
