@@ -32,6 +32,11 @@ class ROC(Metric):
 
     - ``target`` (long tensor): ``(N, ...)`` or ``(N, C, ...)`` with integer labels
 
+    .. note::
+        If either the positive class or negative class is completly missing in the target tensor,
+        the roc values are not well defined in this case and a tensor of zeros will be returned (either fpr
+        or tpr depending on what class is missing) together with an warning.
+
     Args:
         num_classes: integer with number of classes for multi-label and multiclass problems.
             Should be set to ``None`` for binary problems
@@ -103,6 +108,7 @@ class ROC(Metric):
          tensor([1.1837, 0.1837, 0.1338, 0.1183, 0.1138])]
     """
 
+    is_differentiable = False
     preds: List[Tensor]
     target: List[Tensor]
 
@@ -166,7 +172,3 @@ class ROC(Metric):
         if not self.num_classes:
             raise ValueError(f"`num_classes` bas to be positive number, but got {self.num_classes}")
         return _roc_compute(preds, target, self.num_classes, self.pos_label)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
