@@ -13,7 +13,6 @@
 # limitations under the License.
 from typing import Optional
 
-import torch
 from torch import Tensor, tensor
 
 from torchmetrics.utilities.checks import _check_retrieval_functional_inputs
@@ -30,11 +29,15 @@ def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None)
     Args:
         preds: estimated probabilities of each document to be relevant.
         target: ground truth about each document being relevant or not.
-        k: consider only the top k elements (default: None)
+        k: consider only the top k elements (default: None, which considers them all)
 
     Returns:
         a single-value tensor with the precision (at ``k``) of the predictions ``preds`` w.r.t. the labels ``target``.
 
+    Raises:
+        ValueError:
+            If ``k`` parameter is not `None` or an integer larger than 0
+
     Example:
         >>> preds = tensor([0.2, 0.3, 0.5])
         >>> target = tensor([True, False, True])
@@ -52,5 +55,5 @@ def retrieval_precision(preds: Tensor, target: Tensor, k: Optional[int] = None)
     if not target.sum():
         return tensor(0.0, device=preds.device)
 
-    relevant = target[torch.argsort(preds, dim=-1, descending=True)][:k].sum().float()
+    relevant = target[preds.topk(min(k, preds.shape[-1]), dim=-1)[1]].sum().float()
     return relevant / k
