@@ -89,8 +89,8 @@ def _lcs(pred_tokens: List[str], target_tokens: List[str]) -> int:
 
 def _normalize_and_tokenize_text(text: str, stemmer: Optional[Any] = None) -> List[str]:
     """Rouge score should be calculated only over lowercased words and digits. Optionally, Porter stemmer can be
-    used to strip word suffixes to improve matching. The text normalization follows the implemantion from
-    https://github.com/google-research/google-research/blob/master/rouge/tokenize.py.
+    used to strip word suffixes to improve matching. The text normalization follows the implemantion from `Rouge
+    score_Text Normalizition`_
 
     Args:
         text:
@@ -244,13 +244,13 @@ def rouge_score(
     use_stemmer: bool = False,
     rouge_keys: Union[str, Tuple[str, ...]] = ("rouge1", "rouge2", "rougeL", "rougeLsum"),  # type: ignore
 ) -> Dict[str, Tensor]:
-    """Calculate `ROUGE score <https://en.wikipedia.org/wiki/ROUGE_(metric)>`_, used for automatic summarization.
+    """Calculate `Calculate Rouge Score`_ , used for automatic summarization.
 
     Args:
         preds:
-            An iterable of predicted sentences.
+            An iterable of predicted sentences or a single predicted sentence.
         targets:
-            An iterable of target sentences.
+            An iterable of target sentences or a single target sentence.
         use_stemmer:
             Use Porter stemmer to strip word suffixes to improve matching.
         rouge_keys:
@@ -261,8 +261,8 @@ def rouge_score(
         Python dictionary of rouge scores for each input rouge key.
 
     Example:
-        >>> targets = "Is your name John".split()
-        >>> preds = "My name is John".split()
+        >>> targets = "Is your name John"
+        >>> preds = "My name is John"
         >>> from pprint import pprint
         >>> pprint(rouge_score(preds, targets))  # doctest: +NORMALIZE_WHITESPACE +SKIP
         {'rouge1_fmeasure': 0.25,
@@ -285,7 +285,7 @@ def rouge_score(
             If any of the ``rouge_keys`` does not belong to the allowed set of keys.
 
     References:
-        [1] ROUGE: A Package for Automatic Evaluation of Summaries by Chin-Yew Lin https://aclanthology.org/W04-1013/
+        [1] ROUGE: A Package for Automatic Evaluation of Summaries by Chin-Yew Lin. https://aclanthology.org/W04-1013/
     """
 
     if use_stemmer:
