@@ -16,19 +16,18 @@ from typing import Any, Optional, Sequence, Tuple, Union
 import torch
 from torch import Tensor, tensor
 
-from torchmetrics.functional.regression.psnr import _psnr_compute, _psnr_update
+from torchmetrics.functional.image.psnr import _psnr_compute, _psnr_update
 from torchmetrics.metric import Metric
 from torchmetrics.utilities import rank_zero_warn
 
 
 class PSNR(Metric):
     r"""
-    Computes `peak signal-to-noise ratio <https://en.wikipedia.org/wiki/Peak_signal-to-noise_ratio>`_ (PSNR):
+    Computes `Computes Peak Signal-to-Noise Ratio`_ (PSNR):
 
     .. math:: \text{PSNR}(I, J) = 10 * \log_{10} \left(\frac{\max(I)^2}{\text{MSE}(I, J)}\right)
 
-    Where :math:`\text{MSE}` denotes the `mean-squared-error
-    <https://en.wikipedia.org/wiki/Mean_squared_error>`_ function.
+    Where :math:`\text{MSE}` denotes the `mean-squared-error`_ function.
 
     Args:
         data_range:
@@ -70,12 +69,13 @@ class PSNR(Metric):
     """
     min_target: Tensor
     max_target: Tensor
+    higher_is_better = False
 
     def __init__(
         self,
         data_range: Optional[float] = None,
         base: float = 10.0,
-        reduction: str = 'elementwise_mean',
+        reduction: str = "elementwise_mean",
         dim: Optional[Union[int, Tuple[int, ...]]] = None,
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
@@ -87,8 +87,8 @@ class PSNR(Metric):
             process_group=process_group,
         )
 
-        if dim is None and reduction != 'elementwise_mean':
-            rank_zero_warn(f'The `reduction={reduction}` will not have any effect when `dim` is None.')
+        if dim is None and reduction != "elementwise_mean":
+            rank_zero_warn(f"The `reduction={reduction}` will not have any effect when `dim` is None.")
 
         if dim is None:
             self.add_state("sum_squared_error", default=tensor(0.0), dist_reduce_fx="sum")
@@ -107,14 +107,13 @@ class PSNR(Metric):
             self.add_state("min_target", default=tensor(0.0), dist_reduce_fx=torch.min)
             self.add_state("max_target", default=tensor(0.0), dist_reduce_fx=torch.max)
         else:
-            self.add_state("data_range", default=tensor(float(data_range)), dist_reduce_fx='mean')
+            self.add_state("data_range", default=tensor(float(data_range)), dist_reduce_fx="mean")
         self.base = base
         self.reduction = reduction
         self.dim = tuple(dim) if isinstance(dim, Sequence) else dim
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
-        """
-        Update state with predictions and targets.
+        """Update state with predictions and targets.
 
         Args:
             preds: Predictions from model
@@ -134,9 +133,7 @@ class PSNR(Metric):
             self.total.append(n_obs)
 
     def compute(self) -> Tensor:
-        """
-        Compute peak signal-to-noise ratio over state.
-        """
+        """Compute peak signal-to-noise ratio over state."""
         if self.data_range is not None:
             data_range = self.data_range
         else:
