@@ -25,7 +25,7 @@ from torchmetrics.metric import Metric
 
 class MeanAbsoluteError(Metric):
     r"""
-    Computes `mean absolute error <https://en.wikipedia.org/wiki/Mean_absolute_error>`_ (MAE):
+    `Computes Mean Absolute Error`_ (MAE):
 
     .. math:: \text{MAE} = \frac{1}{N}\sum_i^N | y_i - \hat{y_i} |
 
@@ -48,6 +48,8 @@ class MeanAbsoluteError(Metric):
         >>> mean_absolute_error(preds, target)
         tensor(0.5000)
     """
+    is_differentiable = True
+    higher_is_better = False
     sum_abs_error: Tensor
     total: Tensor
 
@@ -83,7 +85,3 @@ class MeanAbsoluteError(Metric):
     def compute(self) -> Tensor:
         """Computes mean absolute error over state."""
         return _mean_absolute_error_compute(self.sum_abs_error, self.total)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return True
