@@ -25,7 +25,7 @@ from torchmetrics.metric import Metric
 
 class MeanSquaredError(Metric):
     r"""
-    Computes `mean squared error <https://en.wikipedia.org/wiki/Mean_squared_error>`_ (MSE):
+    Computes `mean squared error`_ (MSE):
 
     .. math:: \text{MSE} = \frac{1}{N}\sum_i^N(y_i - \hat{y_i})^2
 
@@ -51,6 +51,8 @@ class MeanSquaredError(Metric):
         tensor(0.8750)
 
     """
+    is_differentiable = True
+    higher_is_better = False
     sum_squared_error: Tensor
     total: Tensor
 
@@ -88,7 +90,3 @@ class MeanSquaredError(Metric):
     def compute(self) -> Tensor:
         """Computes mean squared error over state."""
         return _mean_squared_error_compute(self.sum_squared_error, self.total, squared=self.squared)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return True
