@@ -53,6 +53,8 @@ class SpearmanCorrcoef(Metric):
         tensor(1.0000)
 
     """
+    is_differentiable = False
+    higher_is_better = True
     preds: List[Tensor]
     target: List[Tensor]
 
@@ -93,7 +95,3 @@ class SpearmanCorrcoef(Metric):
         preds = dim_zero_cat(self.preds)
         target = dim_zero_cat(self.target)
         return _spearman_corrcoef_compute(preds, target)
-
-    @property
-    def is_differentiable(self) -> bool:
-        return False
