@@ -22,9 +22,7 @@ from torchmetrics.utilities.data import get_group_indexes
 
 
 class RetrievalFallOut(RetrievalMetric):
-    """
-    Computes `Fall-out
-    <https://en.wikipedia.org/wiki/Evaluation_measures_(information_retrieval)#Fall-out>`__.
+    """Computes `Fall-out`_.
 
     Works with binary target data. Accepts float predictions from a model output.
 
@@ -48,6 +46,7 @@ class RetrievalFallOut(RetrievalMetric):
             - ``'skip'``: skip those queries; if all queries are skipped, ``0.0`` is returned
             - ``'error'``: raise a ``ValueError``
 
+        k: consider only the top k elements for each query (default: None, which considers them all)
         compute_on_step:
             Forward only calls ``update()`` and return None if this is set to False. default: True
         dist_sync_on_step:
@@ -59,7 +58,10 @@ class RetrievalFallOut(RetrievalMetric):
         dist_sync_fn:
             Callback that performs the allgather operation on the metric state. When `None`, DDP
             will be used to perform the allgather. default: None
-        k: consider only the top k elements for each query. default: None
+
+    Raises:
+        ValueError:
+            If ``k`` parameter is not `None` or an integer larger than 0
 
     Example:
         >>> from torchmetrics import RetrievalFallOut
@@ -71,21 +73,23 @@ class RetrievalFallOut(RetrievalMetric):
         tensor(0.5000)
     """
 
+    higher_is_better = False
+
     def __init__(
         self,
-        empty_target_action: str = 'pos',
+        empty_target_action: str = "pos",
+        k: int = None,
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
         dist_sync_fn: Callable = None,
-        k: int = None
     ) -> None:
         super().__init__(
             empty_target_action=empty_target_action,
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
             process_group=process_group,
-            dist_sync_fn=dist_sync_fn
+            dist_sync_fn=dist_sync_fn,
         )
 
         if (k is not None) and not (isinstance(k, int) and k > 0):
@@ -93,11 +97,11 @@ class RetrievalFallOut(RetrievalMetric):
         self.k = k
 
     def compute(self) -> Tensor:
-        """
-        First concat state `indexes`, `preds` and `target` since they were stored as lists. After that,
-        compute list of groups that will help in keeping together predictions about the same query.
-        Finally, for each group compute the `_metric` if the number of negative targets is at least
-        1, otherwise behave as specified by `self.empty_target_action`.
+        """First concat state `indexes`, `preds` and `target` since they were stored as lists.
+
+        After that, compute list of groups that will help in keeping together predictions about the same query. Finally,
+        for each group compute the `_metric` if the number of negative targets is at least 1, otherwise behave as
+        specified by `self.empty_target_action`.
         """
         indexes = torch.cat(self.indexes, dim=0)
         preds = torch.cat(self.preds, dim=0)
@@ -111,11 +115,11 @@ class RetrievalFallOut(RetrievalMetric):
             mini_target = target[group]
 
             if not (1 - mini_target).sum():
-                if self.empty_target_action == 'error':
+                if self.empty_target_action == "error":
                     raise ValueError("`compute` method was provided with a query with no negative target.")
-                if self.empty_target_action == 'pos':
+                if self.empty_target_action == "pos":
                     res.append(tensor(1.0))
-                elif self.empty_target_action == 'neg':
+                elif self.empty_target_action == "neg":
                     res.append(tensor(0.0))
             else:
                 # ensure list containt only float tensors
