@@ -22,9 +22,8 @@ from torchmetrics.utilities.imports import _NLTK_AVAILABLE
 
 
 class ROUGEScore(Metric):
-    """Calculate `ROUGE score <https://en.wikipedia.org/wiki/ROUGE_(metric)>`_, used for automatic summarization.
-    This implementation should imitate the behaviour of the `rouge-score` package https://pypi.org/project/rouge-
-    score/.
+    """`Calculate Rouge Score`_, used for automatic summarization. This implementation should imitate the behaviour
+    of the `rouge-score` package `Python ROUGE Implementation`
 
     Args:
         newline_sep:
@@ -51,8 +50,8 @@ class ROUGEScore(Metric):
 
     Example:
 
-        >>> targets = "Is your name John".split()
-        >>> preds = "My name is John".split()
+        >>> targets = "Is your name John"
+        >>> preds = "My name is John"
         >>> rouge = ROUGEScore()   # doctest: +SKIP
         >>> from pprint import pprint
         >>> pprint(rouge(preds, targets))  # doctest: +NORMALIZE_WHITESPACE +SKIP
@@ -76,9 +75,11 @@ class ROUGEScore(Metric):
             If any of the ``rouge_keys`` does not belong to the allowed set of keys.
 
     References:
-        [1] ROUGE: A Package for Automatic Evaluation of Summaries by Chin-Yew Lin https://aclanthology.org/W04-1013/
+        [1] ROUGE: A Package for Automatic Evaluation of Summaries by Chin-Yew Lin `Rouge Detail`_
     """
 
+    higher_is_better = True
+
     def __init__(
         self,
         newline_sep: Optional[bool] = None,  # remove in v0.7
@@ -125,8 +126,8 @@ class ROUGEScore(Metric):
         """Compute rouge scores.
 
         Args:
-            preds: An iterable of predicted sentences.
-            targets: An iterable of target sentences.
+            preds: An iterable of predicted sentences or a single predicted sentence.
+            targets: An iterable of target sentences or a single target sentence.
         """
 
         if isinstance(preds, str):
