@@ -19,12 +19,11 @@ from torch import Tensor
 
 
 def reduce(to_reduce: Tensor, reduction: str) -> Tensor:
-    """
-    Reduces a given tensor by a given reduction method
+    """Reduces a given tensor by a given reduction method.
 
     Args:
-        to_reduce : the tensor, which shall be reduced
-       reduction :  a string specifying the reduction method ('elementwise_mean', 'none', 'sum')
+        to_reduce: the tensor, which shall be reduced
+        reduction:  a string specifying the reduction method ('elementwise_mean', 'none', 'sum')
 
     Return:
         reduced Tensor
@@ -84,8 +83,7 @@ def class_reduce(num: Tensor, denom: Tensor, weights: Tensor, class_reduction: s
         return fraction
 
     raise ValueError(
-        f"Reduction parameter {class_reduction} unknown."
-        f" Choose between one of these: {valid_reduction}"
+        f"Reduction parameter {class_reduction} unknown." f" Choose between one of these: {valid_reduction}"
     )
 
 
@@ -96,11 +94,9 @@ def _simple_gather_all_tensors(result: Tensor, group: Any, world_size: int) -> L
 
 
 def gather_all_tensors(result: Tensor, group: Optional[Any] = None) -> List[Tensor]:
-    """
-    Function to gather all tensors from several ddp processes onto a list that
-    is broadcasted to all processes. Works on tensors that have the same number
-    of dimensions, but where each dimension may differ. In this case tensors are
-    padded, gathered and then trimmed to secure equal workload for all processes
+    """Function to gather all tensors from several ddp processes onto a list that is broadcasted to all processes.
+    Works on tensors that have the same number of dimensions, but where each dimension may differ. In this case
+    tensors are padded, gathered and then trimmed to secure equal workload for all processes.
 
     Args:
         result: the value to sync
