@@ -79,5 +79,13 @@ _ROUGE_SCORE_AVAILABLE: bool = _module_available("rouge_score")
 _BERTSCORE_AVAILABLE: bool = _module_available("bert_score")
 _SCIPY_AVAILABLE: bool = _module_available("scipy")
 _TORCH_FIDELITY_AVAILABLE: bool = _module_available("torch_fidelity")
+_LPIPS_AVAILABLE: bool = _module_available("lpips")
+_PYCOCOTOOLS_AVAILABLE: bool = _module_available("pycocotools")
+_TORCHVISION_AVAILABLE: bool = _module_available("torchvision")
+_TORCHVISION_GREATER_EQUAL_0_8: Optional[bool] = _compare_version("torchvision", operator.ge, "0.8.0")
 _TQDM_AVAILABLE: bool = _module_available("tqdm")
 _TRANSFORMERS_AVAILABLE: bool = _module_available("transformers")
+_PESQ_AVAILABLE: bool = _module_available("pesq")
+_SACREBLEU_AVAILABLE: bool = _module_available("sacrebleu")
+_REGEX_AVAILABLE: bool = _module_available("regex")
+_PYSTOI_AVAILABLE: bool = _module_available("pystoi")
